==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/misc/control/src/main/java/org/openscience/cdk/controller/SwingEventRelay.java <==
/* Copyright (C) 2007  Niels Out <nielsout@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All I ask is that proper credit is given for my work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.controller;

import javax.swing.JComponent;

/**
 * @cdk.module control
 */
public class SwingEventRelay implements IViewEventRelay {

    private JComponent component;

    public SwingEventRelay(JComponent painter) {
        component = painter;
    }

    @Override
    public void updateView() {
        System.out.println("updateView in SwingEventRelay");
        component.repaint();

    }
}

==> cdk_2.9.orig.tar.gz: cdk-cdk-2.9/misc/control/src/main/java/org/openscience/cdk/controller/SwingEventRelay.java <==
/* Copyright (C) 2007  Niels Out <nielsout@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All I ask is that proper credit is given for my work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.controller;

import javax.swing.JComponent;

/**
 * @cdk.module control
 */
public class SwingEventRelay implements IViewEventRelay {

    private final JComponent component;

    public SwingEventRelay(JComponent painter) {
        component = painter;
    }

    @Override
    public void updateView() {
        System.out.println("updateView in SwingEventRelay");
        component.repaint();

    }
}
